@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use autouse 'Carp' => qw(carp croak confess);
 
-our $VERSION = 0.13;
+our $VERSION = 0.14;
 
 =head1 NAME
 
@@ -111,7 +111,7 @@ INIT {
 	      # Do not display progress information
 	      Verbosity => 0,
 
-	      'Link Capacity' => 155_520_000, # Bits per second
+	      'Link Capacity' => 0, # Bits per second
 
 	      # Filename to store TCP traffic in tcpdump format
 	      tcpdump => 0,
@@ -330,17 +330,17 @@ second (b/s).
 
 =over
 
-=item $Trace{IP}{'Total Packets'}
+=item $Trace{IP}{Total}{Packets}
 
-=item $Trace{IP}{'Total Bytes'}
+=item $Trace{IP}{Total}{Bytes}
 
 Number of IP packets and bytes, respectively, in the trace.  The
 number of IP packets should equal the number of records in the trace.
 
 As mentioned earlier, %Trace has virtually the same structure as
 %Interfaces. Therefore, if I<$if> is the interface number,
-C<$Interfaces{$if}{IP}{'Total Packets'}> and
-C<$Interfaces{$if}{IP}{'Total Bytes'}> contain the number of IP
+C<$Interfaces{$if}{IP}{Total}{Packets}> and
+C<$Interfaces{$if}{IP}{Total}{Bytes}> contain the number of IP
 packets and bytes, respectively, observed on interface I<$if>.  The
 same "rule" applies to all %Trace fields presented below.
 
@@ -350,16 +350,16 @@ same "rule" applies to all %Trace fields presented below.
 
 =over
 
-=item $Trace{IP}{'DF Packets'}
+=item $Trace{IP}{DF}{Packets}
 
-=item $Trace{IP}{'DF Bytes'}
+=item $Trace{IP}{DF}{Bytes}
 
 Number of IP packets and bytes, respectively, requesting no
 fragmentation ('Do not Fragment').
 
-=item $Trace{IP}{'MF Packets'}
+=item $Trace{IP}{MF}{Packets}
 
-=item $Trace{IP}{'MF Bytes'}
+=item $Trace{IP}{MF}{Bytes}
 
 Number of IP packets and bytes, respectively, indicating that 'More
 Fragments' follow.
@@ -370,14 +370,14 @@ Fragments' follow.
 
 =over
 
-=item $Trace{IP}{'Normal Packets'}
+=item $Trace{IP}{Normal}{Packets}
 
-=item $Trace{IP}{'Normal Bytes'}
+=item $Trace{IP}{Normal}{Bytes}
 
 Number of IP packets and bytes, respectively, requesting no particular
 treatment (best effort traffic).  No DiffServ or ECN bits are set.
 
-=item $Trace{IP}{'Class Selector Packets'}
+=item $Trace{IP}{'Class Selector'}{Packets}
 
 =item $Trace{IP}{'Class Selector Bytes'}
 
@@ -391,9 +391,9 @@ set.
 Number of IP packets and bytes, respectively, requesting Assured
 Forwarding Per-Hop Behavior (PHB).
 
-=item $Trace{IP}{'EF PHB Packets'}
+=item $Trace{IP}{'EF PHB'}{Packets}
 
-=item $Trace{IP}{'EF PHB Bytes'}
+=item $Trace{IP}{'EF PHB'}{Bytes}
 
 Number of IP packets and bytes, respectively, requesting Expedited
 Forwarding Per-Hop Behavior (PHB)
@@ -404,17 +404,17 @@ Forwarding Per-Hop Behavior (PHB)
 
 =over
 
-=item $Trace{IP}{'ECT Packets'}
+=item $Trace{IP}{ECT}{Packets}
 
-=item $Trace{IP}{'ECT Bytes'}
+=item $Trace{IP}{ECT}{Bytes}
 
 Number of IP packets and bytes, respectively, with either of the ECT
 bits set.  These packets should be carrying traffic from ECN-aware
 hosts.
 
-=item $Trace{IP}{'CE Packets'}
+=item $Trace{IP}{CE}{Packets}
 
-=item $Trace{IP}{'CE Bytes'}
+=item $Trace{IP}{CE}{Bytes}
 
 Number of IP packets and bytes, respectively, with the CE bit set.
 These packets carry ECN-capable traffic that has been marked at an
@@ -422,6 +422,71 @@ ECN-aware router.
 
 =back
 
+=head4 IP Options
+
+=over
+
+=item $Trace{IP}{'No IP Options'}{Packets}
+
+=item $Trace{IP}{'No IP Options'}{Bytes}
+
+Number of IP packets and bytes, respectively, carrying no IP header options.
+
+=item $Trace{IP}{'IP Options'}{Packets}
+
+=item $Trace{IP}{'IP Options'}{Bytes}
+
+Number of IP packets and bytes, respectively, carrying IP header options.
+
+=back
+
+The following diagram summarizes the %Trace data structure up to here.
+
+ Trace
+   - filename
+   - summary
+   - date
+   - starts
+   - ends
+   - records
+   - interfaces
+   - unidirectional
+   - 'Link Capacity'
+   - IP
+       - Total
+           - Packets
+           - Bytes
+       - DF
+           - Packets
+           - Bytes
+       - MF
+           - Packets
+           - Bytes
+       - Normal
+           - Packets
+           - Bytes
+       - 'Class Selector'
+           - Packets
+           - Bytes
+       - 'AF PHB'
+           - Packets
+           - Bytes
+       - 'EF PHB'
+           - Packets
+           - Bytes
+       - ECT
+           - Packets
+           - Bytes
+       - CE
+           - Packets
+           - Bytes
+       - 'No IP Options'
+           - Packets
+           - Bytes
+       - 'IP Options'
+           - Packets
+           - Bytes
+
 =head3 Transport Protocols
 
 Besides the summary information about the trace itself and statistics
@@ -433,22 +498,22 @@ Protocol"> for all transport protocols with an IANA assigned number
 
 =over
 
-=item $Trace{Transport}{TCP}{'Total Packets'}
+=item $Trace{Transport}{TCP}{Total}{Packets}
 
-=item $Trace{Transport}{TCP}{'Total Bytes'}
+=item $Trace{Transport}{TCP}{Total}{Bytes}
 
 Number of TCP segments and the corresponding bytes (including the IP
 and TCP headers) in the trace.
 
-=item $Trace{Transport}{UDP}{'Total Packets'}
+=item $Trace{Transport}{UDP}{Total}{Packets}
 
-=item $Trace{Transport}{UDP}{'Total Bytes'}
+=item $Trace{Transport}{UDP}{Total}{Bytes}
 
 Ditto, for UDP.
 
-=item $Trace{Transport}{ICMP}{'DF Packets'}
+=item $Trace{Transport}{ICMP}{DF}{Packets}
 
-=item $Trace{Transport}{ICMP}{'DF Bytes'}
+=item $Trace{Transport}{ICMP}{DF}{Bytes}
 
 Number of ICMP packets and bytes, respectively, with the DF bit set.
 
@@ -478,8 +543,8 @@ accounts for more than 90% of the total IP traffic, in terms of bytes.
  # ...and generate a summary only if the condition is met.
  #
  write_trace_summary
-    if ( ( $ts_href->{Transport}{TCP}{'Total Bytes'}
-           / $ts_href->{IP}{'Total Bytes'}
+    if ( ( $ts_href->{Transport}{TCP}{Total}{Bytes}
+           / $ts_href->{IP}{Total}{Bytes}
          ) > 0.9
        );
 
@@ -502,9 +567,9 @@ my %Interfaces;
 # this allows us to use more descriptive, i.e. self-documenting hash
 # key names for the data hashes, %Trace and %Interfaces.
 #
-my @data_points = ( 'Total ', 'DF ', 'MF ', 'ECT ', 'CE ',
-		    'Normal ', 'Class Selector ', 'AF PHB ',
-		    'EF PHB ', 'No IP Options ', 'IP Options '
+my @data_points = ( 'Total', 'DF', 'MF', 'ECT', 'CE',
+		    'Normal', 'Class Selector', 'AF PHB', 'EF PHB',
+		    'No IP Options', 'IP Options'
 		  );
 
 =head1 FUNCTIONS
@@ -550,7 +615,7 @@ sub configure ( % ) {
     else {
       $options{$_} = undef;
       shift;
-      carp "Unknown configuration option '$_' ignored";
+      carp "Ignoring unknown configuration option '$_'...";
     }
   }
 }
@@ -645,7 +710,6 @@ sub get_trace_summary_href() {
 
 }
 
-
 =head2 process_trace
 
  process_trace FILENAME
@@ -748,7 +812,7 @@ process_trace() will generate two binary files:
   some.tsh-if2.bin
 
 Each of these files L<can be used in ns2 simulations|"SEE ALSO"> in
-conjunction Application/Traffic/Trace. For example, the following ns2
+conjunction Application/Traffic/Trace.  For example, the following ns2
 script fragment illustrates how to attach F<some.tsh-if2.bin> to a
 traffic source
 
@@ -766,7 +830,10 @@ traffic source
 
  # ...
 
-
+Note that both F<some.tsh-if1.bin> and F<some.tsh-if1.bin> include
+only the I<TCP data-carrying segments> in the trace.  If you want to
+convert the I<entire> TSH trace to Traffic/Trace files, see
+C<converters/tsh2ns2.pl>.
 
 
 =head3 Converting TSH to F<tcpdump>
@@ -955,8 +1022,11 @@ sub process_trace( $ ) {
     ##################################################################
     #                              IP
     ##################################################################
-    $Interfaces{$if}{IP}{'Total Packets'}++;
-    $Interfaces{$if}{IP}{'Total Bytes'} += $ip_len;
+    $Interfaces{$if}{IP}{Total}{Packets}++;
+    $Interfaces{$if}{IP}{Total}{Bytes} += $ip_len;
+
+    # Packet size distribution
+    #
     $Interfaces{$if}{IP}{'Packet Size'}{$ip_len}++;
 
     # Get the IP version
@@ -975,30 +1045,33 @@ sub process_trace( $ ) {
     ##################################################################
     #                      Transport protocols
     ##################################################################
-    $Interfaces{$if}{Transport}{$protocol}{'Total Packets'}++;
-    $Interfaces{$if}{Transport}{$protocol}{'Total Bytes'} += $ip_len;
+    $Interfaces{$if}{Transport}{$protocol}{Total}{Packets}++;
+    $Interfaces{$if}{Transport}{$protocol}{Total}{Bytes} += $ip_len;
+
+    # Packet size distribution
+    #
     $Interfaces{$if}{Transport}{$protocol}{'Packet Size'}{$ip_len}++;
 
     ##################################################################
     #                      D(o not)F(ragment) bit
     ##################################################################
     if ($flags_offset & 0x4000) {
-      $Interfaces{$if}{IP}{'DF Packets'}++;
-      $Interfaces{$if}{IP}{'DF Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{DF}{Packets}++;
+      $Interfaces{$if}{IP}{DF}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'DF Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'DF Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{DF}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{DF}{Bytes} += $ip_len;
     }
 
     ##################################################################
     #                      M(ore)F(ragments) bit
     ##################################################################
     if ($flags_offset & 0x2000) {
-      $Interfaces{$if}{IP}{'MF Packets'}++;
-      $Interfaces{$if}{IP}{'MF Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{MF}{Packets}++;
+      $Interfaces{$if}{IP}{MF}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'MF Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'MF Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{MF}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{MF}{Bytes} += $ip_len;
     }
 
     ##################################################################
@@ -1017,20 +1090,20 @@ sub process_trace( $ ) {
       # (updated ToS definition), RFC 2474 (DiffServ defines DSCP),
       # RFC 2780: No DiffServ code point (DSCP) set
       #
-      $Interfaces{$if}{IP}{'Normal Packets'}++;
-      $Interfaces{$if}{IP}{'Normal Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{Normal}{Packets}++;
+      $Interfaces{$if}{IP}{Normal}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'Normal Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'Normal Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{Normal}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{Normal}{Bytes} += $ip_len;
     }
     elsif ( $dscp % 0b001000 == 0 ) {
       # Class Selector Code points     -- RFC 2474
       #
-      $Interfaces{$if}{IP}{'Class Selector Packets'}++;
-      $Interfaces{$if}{IP}{'Class Selector Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{'Class Selector'}{Packets}++;
+      $Interfaces{$if}{IP}{'Class Selector'}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'Class Selector Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'Class Selector Bytes'}
+      $Interfaces{$if}{Transport}{$protocol}{'Class Selector'}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{'Class Selector'}{Bytes}
 	+=$ip_len;
     }
     elsif ( $dscp % 2 == 0 ) {
@@ -1038,20 +1111,20 @@ sub process_trace( $ ) {
       if ( 0b00100 < $dscp and $dscp < 0b10100 ) {
 	# Assured Forwarding (AF) PHB -- RFC 2597
 	#
-	$Interfaces{$if}{IP}{'AF PHB Packets'}++;
-	$Interfaces{$if}{IP}{'AF PHB Bytes'} += $ip_len;
+	$Interfaces{$if}{IP}{'AF PHB'}{Packets}++;
+	$Interfaces{$if}{IP}{'AF PHB'}{Bytes} += $ip_len;
 
-	$Interfaces{$if}{Transport}{$protocol}{'AF PHB Packets'}++;
-	$Interfaces{$if}{Transport}{$protocol}{'AF PHB Bytes'} += $ip_len;
+	$Interfaces{$if}{Transport}{$protocol}{'AF PHB'}{Packets}++;
+	$Interfaces{$if}{Transport}{$protocol}{'AF PHB'}{Bytes} += $ip_len;
       }
       elsif ( $dscp == 0b10111 ) {
 	# Expedited Forwarding (EF) PHB -- RFC 2598
 	#
-	$Interfaces{$if}{IP}{'EF PHB Packets'}++;
-	$Interfaces{$if}{IP}{'EF PHB Bytes'} += $ip_len;
+	$Interfaces{$if}{IP}{'EF PHB'}{Packets}++;
+	$Interfaces{$if}{IP}{'EF PHB'}{Bytes} += $ip_len;
 
-	$Interfaces{$if}{Transport}{$protocol}{'EF PHB Packets'}++;
-	$Interfaces{$if}{Transport}{$protocol}{'EF PHB Bytes'} += $ip_len;
+	$Interfaces{$if}{Transport}{$protocol}{'EF PHB'}{Packets}++;
+	$Interfaces{$if}{Transport}{$protocol}{'EF PHB'}{Bytes} += $ip_len;
       }
     }
 
@@ -1063,37 +1136,37 @@ sub process_trace( $ ) {
     #
     my $ecn = $tos & 0b11;
     if ( $ecn ) {
-      $Interfaces{$if}{IP}{'ECT Packets'}++;
-      $Interfaces{$if}{IP}{'ECT Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{ECT}{Packets}++;
+      $Interfaces{$if}{IP}{ECT}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'ECT Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'ECT Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{ECT}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{ECT}{Bytes} += $ip_len;
     }
 
     if ( $ecn == 0b11 ) {
-      $Interfaces{$if}{IP}{'CE Packets'}++;
-      $Interfaces{$if}{IP}{'CE Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{CE}{Packets}++;
+      $Interfaces{$if}{IP}{CE}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'CE Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'CE Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{CE}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{CE}{Bytes} += $ip_len;
     }
 
     ##################################################################
     #                          IP Options
     ##################################################################
     if ( $ihl ==  20 ) {
-      $Interfaces{$if}{IP}{'No IP Options Packets'}++;
-      $Interfaces{$if}{IP}{'No IP Options Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{'No IP Options'}{Packets}++;
+      $Interfaces{$if}{IP}{'No IP Options'}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'No IP Options Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'No IP Options Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{'No IP Options'}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{'No IP Options'}{Bytes} += $ip_len;
     }
     elsif ( $ihl > 20 ) {
-      $Interfaces{$if}{IP}{'IP Options Packets'}++;
-      $Interfaces{$if}{IP}{'IP Options Bytes'} += $ip_len;
+      $Interfaces{$if}{IP}{'IP Options'}{Packets}++;
+      $Interfaces{$if}{IP}{'IP Options'}{Bytes} += $ip_len;
 
-      $Interfaces{$if}{Transport}{$protocol}{'IP Options Packets'}++;
-      $Interfaces{$if}{Transport}{$protocol}{'IP Options Bytes'} += $ip_len;
+      $Interfaces{$if}{Transport}{$protocol}{'IP Options'}{Packets}++;
+      $Interfaces{$if}{Transport}{$protocol}{'IP Options'}{Bytes} += $ip_len;
     }
     else {
       # This is an extremely unlikely event, but just in case...
@@ -1322,11 +1395,11 @@ sub process_trace( $ ) {
 
     foreach my $metric ('Packets', 'Bytes') {
       foreach ( @data_points ) {
-	$Trace{IP}{"$_$metric"} += $Interfaces{$if}{IP}{"$_$metric"};
+	$Trace{IP}{$_}{$metric} += $Interfaces{$if}{IP}{$_}{$metric};
 
 	foreach my $protocol ( @transports ) {
-	  $Trace{Transport}{$protocol}{"$_$metric"}
-	    += $Interfaces{$if}{Transport}{$protocol}{"$_$metric"};
+	  $Trace{Transport}{$protocol}{$_}{$metric}
+	    += $Interfaces{$if}{Transport}{$protocol}{$_}{$metric};
 	}
       }
     }
@@ -1372,9 +1445,9 @@ sub process_trace( $ ) {
     while ( my ($k, $v) = each %{$Interfaces{$if}{IP}{'Packet Size'}} ) {
       $Trace{IP}{'Packet Size'}{$k} += $v;
 
-      foreach my $prt ( @transports ) {
-	$Trace{Transport}{$prt}{'Packet Size'}{$k}
-	  += $Interfaces{$if}{Transport}{$prt}{'Packet Size'}{$k};
+      foreach ( @transports ) {
+	$Trace{Transport}{$_}{'Packet Size'}{$k}
+	  += $Interfaces{$if}{Transport}{$_}{'Packet Size'}{$k};
       }
     }
   }
@@ -1383,7 +1456,7 @@ sub process_trace( $ ) {
   #
   my $total_packets;
   while ( ($_) = each %{$Trace{Transport}} ) {
-    $total_packets += $Trace{Transport}{$_}{'Total Packets'};
+    $total_packets += $Trace{Transport}{$_}{Total}{Packets};
   }
 
   croak "Total number of packets is not equal to the number of trace records"
@@ -1455,9 +1528,11 @@ Filename,$Trace{filename},$Trace{date}
 Duration,$Trace{ends}
 Records,$Trace{records}
 Number of Interfaces,$Trace{interfaces}
-Link Capacity,$Trace{'Link Capacity'}
 GENERAL_INFO
 
+  print $FH "Link Capacity,$Trace{'Link Capacity'}\n"
+    if $Trace{'Link Capacity'};
+
   print $FH 'Duplicate timestamps,',
     $Trace{Transport}{TCP}{'Concurrent Segments'}, "\n"
   if $Trace{Transport}{TCP}{'Concurrent Segments'};
@@ -1476,17 +1551,17 @@ INTERFACE_INFO
 
     printf $FH
       "IP Total,%.0f,%.0f,%.0f\n",
-      $href->{IP}{'Total Packets'} / $href->{ends},
-      $href->{IP}{'Total Bytes'} / $href->{IP}{'Total Packets'},
-      $href->{IP}{'Total Bytes'} * 8 / $href->{ends};
+      $href->{IP}{Total}{Packets} / $href->{ends},
+      $href->{IP}{Total}{Bytes} / $href->{IP}{Total}{Packets},
+      $href->{IP}{Total}{Bytes} * 8 / $href->{ends};
 
-    if ( $href->{Transport}{TCP}{'Total Packets'}) {
+    if ( $href->{Transport}{TCP}{Total}{Packets}) {
       printf $FH "TCP Total,%.0f,%.0f,%.0f",
-	$href->{Transport}{TCP}{'Total Packets'} / $href->{ends},
-	( $href->{Transport}{TCP}{'Total Bytes'}
-	  / $href->{Transport}{TCP}{'Total Packets'}
+	$href->{Transport}{TCP}{Total}{Packets} / $href->{ends},
+	( $href->{Transport}{TCP}{Total}{Bytes}
+	  / $href->{Transport}{TCP}{Total}{Packets}
 	),
-	( ( $href->{Transport}{TCP}{'Total Bytes'} * 8 )
+	( ( $href->{Transport}{TCP}{Total}{Bytes} * 8 )
 	  / $href->{ends}
 	);
     }
@@ -1506,14 +1581,14 @@ INTERFACE_INFO
     print $FH join( ',', @data_points), "\nIP";
 
     foreach ( @data_points ) {
-      print_value(\*$FH, $href->{IP}{"$_$metric"});
+      print_value(\*$FH, $href->{IP}{$_}{$metric});
     }
 
     foreach my $protocol ( @transports ) {
       print $FH "\n$protocol";
       foreach ( @data_points ) {
 	print_value( \*$FH,
-	       $href->{Transport}{$protocol}{join "", $_, $metric} );
+	       $href->{Transport}{$protocol}{$_}{$metric} );
       }
     }
   }
@@ -1523,7 +1598,7 @@ INTERFACE_INFO
   if ( $href->{Transport}{TCP}{'Total ACKs'}) {
     print $FH "\n\nTCP ACKNOWLEDGEMENTS";
     foreach ( 'Total ACKs', 'Cumulative ACKs', 'Pure ACKs', 'Options ACKs' ) {
-      print $FH join ",", "\n$_", $href->{Transport}{TCP}{$_};
+      print $FH "\n$_,$href->{Transport}{TCP}{$_}";
     }
   }
 
@@ -1662,8 +1737,8 @@ sub write_trace_summary( ; $ ) {
   croak
     'Important trace information was not found. Call process_trace() before ',
     "calling write_trace_summary().\nTrace summary generation aborted"
-  unless ( $Trace{IP}{'Total Bytes'}
-	   and $Trace{IP}{'Total Packets'}
+  unless ( $Trace{IP}{Total}{Bytes}
+	   and $Trace{IP}{Total}{Packets}
 	   and $Trace{ends}
 	 );
 	
@@ -1728,7 +1803,7 @@ Finally, all exportable functions can be imported with
 
 =head1 VERSION
 
-This is C<Net::Traces::TSH> version 0.13.
+This is C<Net::Traces::TSH> version 0.14.
 
 =head1 SEE ALSO
 
